@@ -1,13 +1,6 @@
-<?php  defined('C5_EXECUTE') or die(_("Access Denied.")); ?>
-<style>
-.rssSummaryList .rssItem{ margin-bottom:16px }
-.rssSummaryList .rssItem .rssItemTitle{ font-weight:bold }
-.rssSummaryList .rssItem .rssItemDate{ color:#999999 }
-.rssSummaryList .rssItem .rssItemSummary{}
-.rssSummaryList .rssSummaryListTitle{font-weight:bold}
-</style>
+<?php  defined('C5_EXECUTE') or die("Access Denied."); ?>
 
-<div id="rssSummaryList<?php echo intval($survey->questionSetId)?>" class="rssSummaryList">
+<div id="rssSummaryList<?php echo intval($bID)?>" class="rssSummaryList">
 
 <?php  if( strlen($title)>0 ){ ?>
 	<div class="rssSummaryListTitle" style="margin-bottom:8px"><?php echo $title?></div>
@@ -17,6 +10,10 @@
 $rssObj=$controller;
 $textHelper = Loader::helper("text"); 
 
+if (!$dateFormat) {
+	$dateFormat = t('F jS');
+}
+
 if( strlen($errorMsg)>0 ){
 	echo $errorMsg;
 }else{
@@ -32,7 +29,7 @@ if( strlen($errorMsg)>0 ){
 					<?php echo  $item->get_title(); ?>
 				</a>
 			</div>
-			<div class="rssItemDate"><?php echo  $item->get_date('F jS'); ?></div>
+			<div class="rssItemDate"><?php echo  $item->get_date($dateFormat); ?></div>
 			<div class="rssItemSummary">
 				<?php 
 				if( $rssObj->showSummary ){
