@@ -27,6 +27,11 @@ if ($controller->hasVoted()) { ?>
 			$graphColors[]=array_pop($availableChartColors);
 			$totalVotes+=intval($opt->getResults());
 		}
+		foreach ($optionResults as &$value){
+			if($totalVotes) {
+				$value=round($value/$totalVotes*100,0);
+			}
+		}		
 		?>
 		
 		<strong><?php echo t("Question")?>: <?php echo $controller->getQuestion()?></strong>
@@ -46,7 +51,7 @@ if ($controller->hasVoted()) { ?>
 					<?php  $i++; ?>
 			<?php  } ?>
 			</table>
-			<div class="note" style="margin-top:8px"><?php echo intval($totalVotes)?> <?php echo (intval($totalVotes)==1)?t('Vote'):t('Votes')?></div>
+			<div class="note" style="margin-top:8px"><?php echo t2('%d Vote', '%d Votes', intval($totalVotes), intval($totalVotes))?></div>
 		</div>
 		<?php 
 		//&chl= join('|',$optionNamesAbbrev) 
@@ -93,4 +98,4 @@ if ($controller->hasVoted()) { ?>
 
 <?php  } ?>
 
-</div>
\ No newline at end of file
+</div>
