@@ -79,8 +79,19 @@ class Concrete5_Controller_Block_Form extends BlockController {
 	}
 	
 	public function on_page_view() {
-		$this->addFooterItem(Loader::helper('html')->css('jquery.ui.css'));
-		$this->addFooterItem(Loader::helper('html')->javascript('jquery.ui.js'));
+		if ($this->viewRequiresJqueryUI()) {
+			$this->addHeaderItem(Loader::helper('html')->css('jquery.ui.css'));
+			$this->addFooterItem(Loader::helper('html')->javascript('jquery.ui.js'));
+		}
+	}
+	
+	//Internal helper function
+	private function viewRequiresJqueryUI() {
+		$whereInputTypes = "inputType = 'date' OR inputType = 'datetime'";
+		$sql = "SELECT COUNT(*) FROM {$this->btQuestionsTablename} WHERE questionSetID = ? AND bID = ? AND ({$whereInputTypes})";
+		$vals = array(intval($this->questionSetId), intval($this->bID));
+		$JQUIFieldCount = Loader::db()->GetOne($sql, $vals);
+		return (bool)$JQUIFieldCount;
 	}
 	
 	public function getDefaultThankYouMsg() {
@@ -442,23 +453,17 @@ class Concrete5_Controller_Block_Form extends BlockController {
 				//echo $mh->body.'<br>';
 				@$mh->sendMail(); 
 			} 
-			//$_REQUEST=array();	
 			
-			if($this->redirectCID > 0) {
-				$pg = Page::getByID($this->redirectCID);
-				if(is_object($pg)) {
-					$this->redirect($pg->getCollectionPath());
-				} else { // page didn't exist, we'll just do the default action
-					$c = Page::getCurrentPage();
-					header("Location: ".Loader::helper('navigation')->getLinkToCollection($c, true)."?surveySuccess=1&qsid=".$this->questionSetId."#".$this->questionSetId);
-					exit;
+			if (!$this->noSubmitFormRedirect) {
+				if ($this->redirectCID > 0) {
+					$pg = Page::getByID($this->redirectCID);
+					if (is_object($pg) && $pg->cID) {
+						$this->redirect($pg->getCollectionPath());
+					}
 				}
-			}
-			
-			if(!$this->noSubmitFormRedirect){
 				$c = Page::getCurrentPage();
 				header("Location: ".Loader::helper('navigation')->getLinkToCollection($c, true)."?surveySuccess=1&qsid=".$this->questionSetId."#".$this->questionSetId);
-				die;
+				exit;
 			}
 		}
 	}		
