@@ -64,8 +64,7 @@ defined('C5_EXECUTE') or die("Access Denied.");
 		public function getInstance() {
 			static $instance;
 			if (!isset($instance)) {
-				$v = __CLASS__;
-				$instance = new $v;
+				$instance = new View();
 			}
 			return $instance;
 		}		
@@ -98,8 +97,37 @@ defined('C5_EXECUTE') or die("Access Denied.");
 		public function getStyleSheet($stylesheet) {
 			if ($this->isPreview()) {
 				return REL_DIR_FILES_TOOLS . '/css/' . DIRNAME_THEMES . '/' . $this->getThemeHandle() . '/' . $stylesheet . '?mode=preview&time=' . time();
-			} else {
-				return REL_DIR_FILES_TOOLS . '/css/' . DIRNAME_THEMES . '/' . $this->getThemeHandle() . '/' . $stylesheet;
+			}
+			$pt = PageTheme::getByHandle($this->getThemeHandle());
+			$file = $this->getThemePath() . '/' . $stylesheet;
+			$cacheFile = DIR_FILES_CACHE . '/' . DIRNAME_CSS . '/' . $this->getThemeHandle() . '/' . $stylesheet;
+			$env = Environment::get();
+			$themeRec = $env->getUncachedRecord(DIRNAME_THEMES . '/' . $this->getThemeHandle() . '/' . $stylesheet, $pt->getPackageHandle());
+			if (file_exists($cacheFile) && $themeRec->exists()) {
+				if (filemtime($cacheFile) > filemtime($themeRec->file)) {
+					return REL_DIR_FILES_CACHE . '/' . DIRNAME_CSS . '/' . $this->getThemeHandle() . '/' . $stylesheet;
+				}
+			}
+			if ($themeRec->exists()) {
+				$themeFile = $themeRec->file;
+				if (!file_exists(DIR_FILES_CACHE . '/' . DIRNAME_CSS)) {
+					@mkdir(DIR_FILES_CACHE . '/' . DIRNAME_CSS);
+				}
+				if (!file_exists(DIR_FILES_CACHE . '/' . DIRNAME_CSS . '/' . $this->getThemeHandle())) {
+					@mkdir(DIR_FILES_CACHE . '/' . DIRNAME_CSS . '/' . $this->getThemeHandle());
+				}
+				$fh = Loader::helper('file');
+				$stat = filemtime($themeFile);
+				if (!file_exists(dirname($cacheFile))) {
+					@mkdir(dirname($cacheFile), DIRECTORY_PERMISSIONS_MODE, true);
+				}
+				$style = $pt->parseStyleSheet($stylesheet);
+				$r = @file_put_contents($cacheFile, $style);
+				if ($r) {
+					return REL_DIR_FILES_CACHE . '/' . DIRNAME_CSS . '/' . $this->getThemeHandle() . '/' . $stylesheet;
+				} else {
+					return $this->getThemePath() . '/' . $stylesheet;
+				}
 			}
 		}
 
@@ -703,6 +731,8 @@ defined('C5_EXECUTE') or die("Access Denied.");
 				}
 			}
 			
+			$dsh = Loader::helper('concrete/dashboard');
+
 			$wrapTemplateInTheme = false;
 			$this->checkMobileView();
 			Events::fire('on_start', $this);
@@ -724,26 +754,12 @@ defined('C5_EXECUTE') or die("Access Denied.");
 			if ($view instanceof Page) {
 
 				$_pageBlocks = $view->getBlocks();
-				$_pageBlocksGlobal = $view->getGlobalBlocks();
-				$_pageBlocks = array_merge($_pageBlocks, $_pageBlocksGlobal);
-				if ($view->supportsPageCache($_pageBlocks, $this->controller)) {
-					$pageContent = $view->getFromPageCache();
-					if ($pageContent != false) {
-						Events::fire('on_before_render', $this);
-						if (defined('APP_CHARSET')) {
-							header("Content-Type: text/html; charset=" . APP_CHARSET);
-						}
-						print($pageContent);
-						Events::fire('on_render_complete', $this);
-						if (ob_get_level() == OB_INITIAL_LEVEL) {
-	
-							require(DIR_BASE_CORE . '/startup/shutdown.php');
-							exit;
-						}
-						return;
-					}
+
+				if (!$dsh->inDashboard()) {
+					$_pageBlocksGlobal = $view->getGlobalBlocks();
+					$_pageBlocks = array_merge($_pageBlocks, $_pageBlocksGlobal);
 				}
-				
+
 				// do we have any custom menu plugins?
 				$cp = new Permissions($view);
 				if ($cp->canViewToolbar()) { 
@@ -837,7 +853,7 @@ defined('C5_EXECUTE') or die("Access Denied.");
 			
 			if (is_object($this->c)) {
 				$c = $this->c;
-				if (defined('DB_DATABASE') && $view == '/page_not_found') {
+				if (defined('DB_DATABASE') && ($view == '/page_not_found' || $view == '/login')) {
 					$view = $c;
 					$req = Request::get();
 					$req->setCurrentPage($c);
@@ -903,6 +919,12 @@ defined('C5_EXECUTE') or die("Access Denied.");
 			
 			if (file_exists($this->theme)) {
 				
+				$cache = PageCache::getLibrary();
+				$shouldAddToCache = $cache->shouldAddToCache($this);
+				if ($shouldAddToCache) {
+					$cache->outputCacheHeaders($c);
+				}
+
 				ob_start();
 				include($this->theme);
 				$pageContent = ob_get_contents();
@@ -911,16 +933,17 @@ defined('C5_EXECUTE') or die("Access Denied.");
 				$ret = Events::fire('on_page_output', $pageContent);
 				if($ret != '') {
 					print $ret;
+					$pageContent = $ret;
 				} else {
 					print $pageContent;
 				}
-				
-				if ($view instanceof Page) {
-					if ($view->supportsPageCache($_pageBlocks, $this->controller)) {
-						$view->addToPageCache($pageContent);
-					}
+
+				$cache = PageCache::getLibrary();
+				if ($shouldAddToCache) {
+					$cache->set($c, $pageContent);
 				}
-				
+
+			
 			} else {
 				throw new Exception(t('File %s not found. All themes need default.php and view.php files in them. Consult concrete5 documentation on how to create these files.', $this->theme));
 			}
