@@ -1,6 +1,6 @@
 <?php 
 
-defined('C5_EXECUTE') or die(_("Access Denied."));
+defined('C5_EXECUTE') or die("Access Denied.");
 
 /**
  * Checks to see if magic_quotes_gpc is enabled, if so we process all the input. Blah
@@ -9,7 +9,7 @@ defined('C5_EXECUTE') or die(_("Access Denied."));
  */
  
  if (get_magic_quotes_gpc()) {
-	$in = array(&$_GET, &$_POST, &$_COOKIE);
+	$in = array(&$_GET, &$_POST, &$_COOKIE, &$_REQUEST);
 	while (list($k,$v) = each($in)) {
 		foreach ($v as $key => $val) {
 			if (!is_array($val)) {
