@@ -1,8 +1,7 @@
 <?php 
-defined('C5_EXECUTE') or die(_("Access Denied."));
+defined('C5_EXECUTE') or die("Access Denied.");
 $this->inc('elements/header.php'); ?>
 
-
 	<div id="central">
 		<div id="sidebar">
 			<?php 
@@ -13,10 +12,8 @@ $this->inc('elements/header.php'); ?>
 		
 		<div id="body">	
 			<?php 
-			
 			$a = new Area('Main');
 			$a->display($c);
-			
 			?>
 		</div>
 		
