@@ -1,6 +1,7 @@
 <?php 
-defined('C5_EXECUTE') or die(_("Access Denied."));
+defined('C5_EXECUTE') or die("Access Denied.");
+//not working? try $_GET['force']=1
 $v = View::getInstance();
 $v->setTheme('concrete');
 $v->render('/upgrade');
-exit;
+exit;
\ No newline at end of file
